-- X-ray calculations

-- store the global value of hc (keV-nm)
hc = 1.239841856
aB_m = 0.52917720859e-10	-- Bohr radius (m)


-- store the common d-spacings (nm)
Si = 0.54310206
Ge = 0.56577974
Cu = 0.361496
Al = 0.40495
SrTiO3 = 0.39051

-- globals to hold known values (need to know 2 of the three), keV, sinTheta and d (nm)
keV = 10							-- init to 10 keV
dspace = Si / sqrt(3)				-- init to Si 111
sinTheta = NaN						-- init to NaN


-- get keV (keV) from the stack and save in global
function load_keV(x)
	keV = x
	return
end

-- get d-spacing (nm) from the stack and save in global
function load_dspace(x)
	dspace = x
	return
end

-- get theta (degree) from the stack and save sin(theta) in global
function load_theta(x)
	local theta = x * pi / 180
	sinTheta = sin(theta)
	return
end


-- put hc (keV-nm) on the stack
function put_hc()
	return hc
end


-- put theta (degree) on the stack, calculate from keV and dspace
function put_theta()
	local degree = asin( hc / (keV*2*dspace) ) * 180/pi
	return degree
end

-- put energy (keV) on the stack, calculate from theta and dspace
function put_keV()
	return (hc / (2*dspace * sinTheta))
end

-- put d-spacing (nm) on the stack, calculate from keV and theta
function put_dspace()
	return (hc/(2 * keV * sinTheta))
end

-- put Q (1/nm) on the stack, calculate from keV and theta
function put_Q()
	local d = (hc/(2 * keV * sinTheta))
	return (2* pi / d)
end



Buttons for d-spacings:
	button puts Si
	button puts Ge
	button puts Cu
	button puts Al
	button puts SrTiO3


--	Button layout
--
--		keV>		d>		theta>		hc
--		->keV		->d		->theta		->Q
--
--
--	button "keV>"	stores x into local energy (kev)
--	button "d>"		stores x into local d-spacing (nm)
--	button "theta>"	stores x into local theta (reads degrees, saves radian)
--	button "hc"		puts hc on the stack
--
--	button "->keV"	calculates keV from internal values of theta and dspace
--	button "->d"	calculates dspace from internal values of theta and keV
--	button "->theta"calculates theta from internal values of keV and dspace
--	button "->Q"	calculates Q from internal values of theta and keV


